"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const react_1 = require("react");
const react_hooks_global_state_1 = require("react-hooks-global-state");
const initialState = {
    whatsappNumber: '',
    email: '',
    adminFee: 0,
    termsAndConditions: '',
    aboutUs: '',
    privacyPolicy: '',
    aboutRefund: '',
};
const { useGlobalState } = (0, react_hooks_global_state_1.createGlobalState)(initialState);
function useConfig() {
    const [whatsappNumber, setWhatsappNumber] = useGlobalState('whatsappNumber');
    const [email, setEmail] = useGlobalState('email');
    const [adminFee, setAdminFee] = useGlobalState('adminFee');
    const [tnc, setTnc] = useGlobalState('termsAndConditions');
    const [aboutUs, setAboutUs] = useGlobalState('aboutUs');
    const [privacyPolicy, setPrivacyPolicy] = useGlobalState('privacyPolicy');
    const [aboutRefund, setAboutRefund] = useGlobalState('aboutRefund');
    (0, react_1.useEffect)(() => {
        const listConfig = [
            'ADMIN_FEE',
            'WHATSAPP_PHONE_NUMBER',
            'TERMS_AND_CONDITIONS',
            'ABOUT_US',
            'PRIVACY_POLICY',
            'ABOUT_REFUND',
        ];
        const fetchConfig = async () => {
            var _a;
            const res = await axios_1.default.get('/app-configs?keys=' + listConfig.join(','));
            return (_a = res === null || res === void 0 ? void 0 : res.data) === null || _a === void 0 ? void 0 : _a.payload.results;
        };
        fetchConfig().then((res) => {
            const config = res === null || res === void 0 ? void 0 : res.reduce((acc, cur) => {
                acc[cur.key] = cur.value;
                return acc;
            }, {});
            if (config === null || config === void 0 ? void 0 : config.WHATSAPP_PHONE_NUMBER) {
                setWhatsappNumber(config.WHATSAPP_PHONE_NUMBER.replace('+', ''));
            }
            if (config === null || config === void 0 ? void 0 : config.ADMIN_FEE) {
                setAdminFee(Number(config.ADMIN_FEE));
            }
            if (config === null || config === void 0 ? void 0 : config.EMAIL_ADDRESS) {
                setEmail(config.EMAIL_ADDRESS);
            }
            if (config === null || config === void 0 ? void 0 : config.TERMS_AND_CONDITIONS) {
                setTnc(config.TERMS_AND_CONDITIONS);
            }
            if (config === null || config === void 0 ? void 0 : config.ABOUT_US) {
                setAboutUs(config.ABOUT_US);
            }
            if (config === null || config === void 0 ? void 0 : config.PRIVACY_POLICY) {
                setPrivacyPolicy(config.PRIVACY_POLICY);
            }
            if (config === null || config === void 0 ? void 0 : config.ABOUT_REFUND) {
                setAboutRefund(config.ABOUT_REFUND);
            }
        });
    }, []);
    return {
        whatsappNumber,
        email,
        adminFee,
        tnc,
        aboutUs,
        privacyPolicy,
        aboutRefund,
        setWhatsappNumber,
        setEmail,
        setAdminFee,
    };
}
exports.default = useConfig;
